@@ -1,5 +1,5 @@
 /*  Evoution RSS Reader Plugin
- *  Copyright (C) 2007-2009 Lucian Langa <cooly@gnome.eu.org>
+ *  Copyright (C) 2007-2012 Lucian Langa <cooly@gnome.eu.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,17 +22,16 @@
 #include <glib/gi18n.h>
 
 #include <mail/em-utils.h>
-#if (EVOLUTION_VERSION >= 22900) //kb//
+
 #if (EVOLUTION_VERSION >= 30391) //kb//
 #include <libevolution-utils/e-alert-dialog.h>
 #else
 #include <e-util/e-alert-dialog.h>
 #endif
+
 #include <shell/e-shell-taskbar.h>
 #include <shell/e-shell-view.h>
-#else
-#include <e-util/e-error.h>
-#endif
+
 
 extern int rss_verbose_debug;
 
@@ -40,9 +39,7 @@ extern int rss_verbose_debug;
 #include "network-soup.h"
 #include "notification.h"
 
-#if (EVOLUTION_VERSION >= 22900) //kb//
 extern EShellView *rss_shell_view;
-#endif
 extern rssfeed *rf;
 
 #if (EVOLUTION_VERSION < 29102)
@@ -69,15 +66,10 @@ rss_error(gpointer key, gchar *name, gchar *error, gchar *emsg)
 #if (EVOLUTION_VERSION < 29102)
 	gpointer newkey;
 #endif
-#if (EVOLUTION_VERSION >= 22900) //kb//
 	EShell *shell;
 	EMailBackend *backend;
 	GtkWindow *parent;
 	GList *windows;
-#else
-	EActivityHandler *activity_handler;
-	guint id;
-#endif
 #if (EVOLUTION_VERSION >= 30101)
 	gpointer alert;
 #endif
@@ -92,7 +84,6 @@ rss_error(gpointer key, gchar *name, gchar *error, gchar *emsg)
 
 	if (key) {
 		if (!g_hash_table_lookup(rf->error_hash, key)) {
-#if (EVOLUTION_VERSION >= 22900) //kb//
 			shell = e_shell_get_default ();
 #if (EVOLUTION_VERSION >= 30101)
 			alert = e_alert_new ("org-gnome-evolution-rss:feederr",
@@ -126,10 +117,6 @@ rss_error(gpointer key, gchar *name, gchar *error, gchar *emsg)
 				"org-gnome-evolution-rss:feederr",
 				error, msg, NULL);
 #endif
-#else
-			ed = e_error_new(NULL, "org-gnome-evolution-rss:feederr",
-				error, msg, NULL);
-#endif
 #if (EVOLUTION_VERSION < 29102)
 			newkey = g_strdup(key);
 			g_signal_connect(
@@ -150,32 +137,17 @@ rss_error(gpointer key, gchar *name, gchar *error, gchar *emsg)
 #endif
 
 #if (EVOLUTION_VERSION < 29102)
-#if (EVOLUTION_VERSION >= 22900) //kb//
 		em_utils_show_error_silent(ed);
 		g_hash_table_insert(
 			rf->error_hash,
 			newkey,
 			GINT_TO_POINTER(1));
-
-#else
-		activity_handler =
-			mail_component_peek_activity_handler (mail_component_peek());
-		id = e_activity_handler_make_error (
-			activity_handler,
-			(char *)mail_component_peek(),
-			E_LOG_ERROR,
-			ed);
-		g_hash_table_insert(rf->error_hash,
-			newkey,
-			GINT_TO_POINTER(id));
-#endif
 #endif
 		}
 		goto out;
 	}
 
 	if (!rf->errdialog) {
-#if (EVOLUTION_VERSION >= 22900) //kb//
 		shell = e_shell_get_default ();
 #if (EVOLUTION_VERSION >= 30301)
 		application = GTK_APPLICATION(shell);
@@ -188,11 +160,6 @@ rss_error(gpointer key, gchar *name, gchar *error, gchar *emsg)
 		ed  = e_alert_dialog_new_for_args(parent,
 			"org-gnome-evolution-rss:feederr",
 			error, msg, NULL);
-#else
-		ed  = e_error_new(NULL,
-			"org-gnome-evolution-rss:feederr",
-			error, msg, NULL);
-#endif
 		g_signal_connect(
 			ed,
 			"response",
@@ -209,84 +176,41 @@ out:    g_free(msg);
 void
 taskbar_push_message(gchar *message)
 {
-#if EVOLUTION_VERSION < 22900 //kb//
-	EActivityHandler *activity_handler =
-		mail_component_peek_activity_handler (mail_component_peek ());
-	e_activity_handler_set_message(activity_handler, message);
-#else
 	EShellTaskbar *shell_taskbar;
 	g_return_if_fail(rss_shell_view != NULL);
 	shell_taskbar = e_shell_view_get_shell_taskbar (rss_shell_view);
 	e_shell_taskbar_set_message (shell_taskbar, message);
-#endif
 }
 
 void
 taskbar_pop_message(void)
 {
-#if EVOLUTION_VERSION < 22900 //kb//
-	EActivityHandler *activity_handler =
-		mail_component_peek_activity_handler (mail_component_peek ());
-	e_activity_handler_unset_message(activity_handler);
-#else
 	EShellTaskbar *shell_taskbar;
 	g_return_if_fail(rss_shell_view != NULL);
 	shell_taskbar = e_shell_view_get_shell_taskbar (rss_shell_view);
 	e_shell_taskbar_set_message (shell_taskbar, "");
-#endif
 }
 
 void
-#if EVOLUTION_VERSION > 29102
 taskbar_op_abort(CamelOperation *cancellable, gpointer key)
-#else
-taskbar_op_abort(gpointer key)
-#endif
 {
-#if EVOLUTION_VERSION < 22900 //kb//
-	EActivityHandler *activity_handler =
-		mail_component_peek_activity_handler (mail_component_peek ());
-	guint activity_key =
-		GPOINTER_TO_INT(g_hash_table_lookup(rf->activity, key));
-	if (activity_key)
-		e_activity_handler_operation_finished(
-				activity_handler,
-				activity_key);
-#else
 	EActivity *activity = g_hash_table_lookup(rf->activity, key);
 	e_activity_set_state (activity, E_ACTIVITY_CANCELLED);
 	g_hash_table_remove(rf->activity, key);
 	g_object_unref(activity);
 	abort_all_soup();
-#endif
 }
 
-#if EVOLUTION_VERSION >= 22900 //kb//
 EActivity *
-#else
-guint
-#endif
 taskbar_op_new(gchar *message, gpointer key);
 
-#if EVOLUTION_VERSION >= 22900 //kb//
 EActivity *
-#else
-guint
-#endif
 taskbar_op_new(gchar *message, gpointer key)
 {
-#if EVOLUTION_VERSION >= 22900 //kb//
 	EShell *shell;
 	EShellBackend *shell_backend;
 	EActivity *activity;
 	GCancellable *cancellable;
-#else
-	EActivityHandler *activity_handler;
-	char *mcp;
-	guint activity_id;
-#endif
-
-#if EVOLUTION_VERSION >= 22900 //kb//
 
 	shell = e_shell_get_default ();
 	shell_backend = e_shell_get_backend_by_name (shell, "mail");
@@ -313,123 +237,58 @@ taskbar_op_new(gchar *message, gpointer key)
 		key);
 	g_object_unref (cancellable);
 	return activity;
-#else
-	activity_handler =
-		mail_component_peek_activity_handler (mail_component_peek ());
-	mcp = g_strdup_printf("%p", mail_component_peek());
-	activity_id =
-		e_activity_handler_cancelable_operation_started(
-			activity_handler,
-			"evolution-mail",
-			message,
-			TRUE,
-			(void (*) (gpointer))taskbar_op_abort,
-			key);
-	g_free(mcp);
-	return activity_id;
-#endif //kb//
 }
 
 void
 taskbar_op_set_progress(gchar *key, gchar *msg, gdouble progress)
 {
-#if (EVOLUTION_VERSION < 22900) //kb//
-	EActivityHandler *activity_handler;
-	guint activity_id;
-#else
 	EActivity *activity_id;
-#endif
 
 	g_return_if_fail(key != NULL);
 
-#if (EVOLUTION_VERSION < 22900) //kb//
-	activity_handler = mail_component_peek_activity_handler
-				(mail_component_peek ());
-	activity_id = GPOINTER_TO_INT(
-				g_hash_table_lookup(rf->activity, key));
-#else
 	activity_id = g_hash_table_lookup(rf->activity, key);
-#endif
 
 	if (activity_id) {
-#if (EVOLUTION_VERSION < 22900) //kb//
-		e_activity_handler_operation_progressing(
-			activity_handler,
-			activity_id,
-			g_strdup(msg),
-			progress);
-#else
-	e_activity_set_percent (activity_id, progress);
-#endif
+		e_activity_set_percent (activity_id, progress);
 	}
 }
 
 void
 taskbar_op_finish(gchar *key)
 {
-#if (EVOLUTION_VERSION >= 22900) //kb//
 	EActivity *aid = NULL;
 	EActivity *activity_key;
-#else
-	guint aid = 0;
-	guint activity_key;
-	EActivityHandler *activity_handler = mail_component_peek_activity_handler (
-						mail_component_peek ());
-#endif
 	if (key) {
-#if (EVOLUTION_VERSION >= 22900) //kb//
 		aid = (EActivity *)g_hash_table_lookup(rf->activity, key);
-#else
-		aid = (guint)g_hash_table_lookup(rf->activity, key);
-#endif
 	}
 	if (aid == NULL) {
-#if (EVOLUTION_VERSION >= 22900) //kb//
 		activity_key = g_hash_table_lookup(rf->activity, "main");
-#else
-		activity_key = GPOINTER_TO_INT(g_hash_table_lookup(rf->activity, "main"));
-#endif
 		if (activity_key) {
 			d("activity_key:%p\n", (gpointer)activity_key);
-#if (EVOLUTION_VERSION >= 22900) //kb//
 #if (EVOLUTION_VERSION >= 29102)
 			e_activity_set_state (activity_key, E_ACTIVITY_COMPLETED);
 			g_object_unref(activity_key);
 #else
 			e_activity_complete (activity_key);
-#endif
-#else
-			e_activity_handler_operation_finished(activity_handler, activity_key);
 #endif
 			g_hash_table_remove(rf->activity, "main");
 		}
 	} else {
-#if (EVOLUTION_VERSION >= 22900) //kb//
 #if (EVOLUTION_VERSION >= 29102)
 		e_activity_set_state (aid, E_ACTIVITY_COMPLETED);
 		g_object_unref(aid);
 #else
 		e_activity_complete (aid);
-#endif
-#else
-		e_activity_handler_operation_finished(activity_handler, aid);
 #endif
 		g_hash_table_remove(rf->activity, key);
 	}
 }
 
-#if (EVOLUTION_VERSION >= 22900) //kb//
 EActivity*
-#else
-guint
-#endif
 taskbar_op_message(gchar *msg, gchar *unikey)
 {
 		gchar *tmsg;
-#if (EVOLUTION_VERSION >= 22900) //kb//
 		EActivity *activity_id;
-#else
-#endif
 		if (!msg) {
 			tmsg = g_strdup_printf(
 				_("Fetching Feeds (%d enabled)"),
@@ -438,7 +297,6 @@ taskbar_op_message(gchar *msg, gchar *unikey)
 		} else
 			tmsg = g_strdup(msg);
 
-#if (EVOLUTION_VERSION >= 22900) //kb//
 		if (!msg)
 			activity_id =
 				(EActivity *)taskbar_op_new(
@@ -447,12 +305,6 @@ taskbar_op_message(gchar *msg, gchar *unikey)
 		else
 			activity_id =
 				(EActivity *)taskbar_op_new(tmsg, msg);
-#else
-		if (!msg)
-			activity_id = taskbar_op_new(tmsg, unikey);
-		else
-			activity_id = taskbar_op_new(tmsg, msg);
-#endif
 		g_hash_table_insert(
 			rf->activity,
 			GUINT_TO_POINTER(unikey),
