@@ -30,13 +30,27 @@
 #else
 #include <mail/mail-ops.h>
 #endif
+#if EVOLUTION_VERSION >= 30505
+#include <mail/e-mail-reader-utils.h>
+#endif
+
+#if (EVOLUTION_VERSION > 30501)
+#include <em-format/e-mail-formatter.h>
+#else
 #include <mail/em-format-html.h>
+#endif
+
 #if (DATASERVER_VERSION >= 2031001)
 #include <camel/camel.h>
 #else
 #include <camel/camel-url.h>
 #endif
+
+#if (DATASERVER_VERSION > 3005001)
+#include <libedataserver/libedataserver.h>
+#else
 #include <libedataserver/e-data-server-util.h>
+#endif
 
 extern int rss_verbose_debug;
 
@@ -49,7 +63,7 @@ extern int rss_verbose_debug;
 #include "misc.h"
 #include "network-soup.h"
 
-extern GConfClient *rss_gconf;
+//extern GConfClient *rss_gconf;
 void asyncr_context_free(AsyncData *asyncr);
 GQueue *display_channel_items_sync(AsyncData *ayncr);
 
@@ -81,7 +95,11 @@ rss_html_url_decode(const char *html, int len)
 		if ((url = (gchar *)xmlGetProp((xmlNodePtr)doc, (xmlChar *)"src"))) {
 			if (strstr(url, "img:")) {
 				gchar *tmp = decode_image_cache_filename(url);
+#if (EVOLUTION_VERSION < 30400)
 				duri = g_strconcat("file://", tmp, NULL);
+#else
+				duri = g_strconcat("evo-file://", tmp, NULL);
+#endif
 				g_free(tmp);
 				xmlSetProp(
 					(xmlNodePtr)doc,
@@ -941,7 +959,8 @@ tree_walk (xmlNodePtr root, RDF *r)
 static const char *html_const[4] = {"img", "a", NULL};
 
 gchar *
-process_images(gchar *text, gchar *link, gboolean decode, EMFormatHTML *format)
+//process_images(gchar *text, gchar *link, gboolean decode, EMFormatHTML *format)
+process_images(gchar *text, gchar *link, gboolean decode, EMailFormatter *format)
 {
 	xmlChar *buff = NULL;
 	guint size = 0;
@@ -959,6 +978,9 @@ process_images(gchar *text, gchar *link, gboolean decode, EMFormatHTML *format)
 #if (EVOLUTION_VERSION >= 23000)
 						g_free(name);
 						name = g_filename_to_uri (tname, NULL, NULL);
+#if (EVOLUTION_VERSION < 30400)
+						name = g_strconcat("evo-", name, NULL);
+#endif
 						g_free(tname);
 #else
 						name = tname;
@@ -1236,22 +1258,6 @@ parse_channel_line(xmlNode *top, gchar *feed_name, RDF *r, gchar **article_uid)
 
 }
 
-void
-refresh_mail_folder(CamelFolder *mail_folder);
-
-void
-refresh_mail_folder(CamelFolder *mail_folder)
-{
-	mail_refresh_folder(mail_folder, NULL, NULL);
-#if (DATASERVER_VERSION >= 2033001)
-		camel_folder_synchronize (mail_folder, FALSE, G_PRIORITY_DEFAULT,
-			NULL, NULL, NULL);
-#else
-	camel_folder_sync(mail_folder, FALSE, NULL);
-#endif
-	camel_folder_thaw(mail_folder);
-}
-
 GQueue *
 display_channel_items_sync(AsyncData *asyncr)
 {
@@ -1332,6 +1338,7 @@ display_channel_items_sync(AsyncData *asyncr)
 		subj = g_strdup(CF->subj);
 
 		ftotal++;
+#if 0
 		if (gconf_client_get_bool(rss_gconf, GCONF_KEY_DOWNLOAD_ENCLOSURES, NULL)) {
 			if (CF->encl) {
 				process_enclosure(CF);
@@ -1341,6 +1348,7 @@ display_channel_items_sync(AsyncData *asyncr)
 				goto done;
 			}
 		}
+#endif
 
 		if (!freeze) {
 			camel_folder_freeze(mail_folder);
