@@ -31,5 +31,5 @@
 GdkPixbuf *rss_build_icon(const gchar *icon_name,
 			GtkIconSize icon_size);
 void rss_build_stock_images(void);
-void init_rss_builtin_images(void);
+void rss_append_folder_icons(gchar *key);
 
