@@ -20,9 +20,21 @@
 #include <glib.h>
 #include <glib/gstdio.h>
 #include <camel/camel.h>
+
+#if (DATASERVER_VERSION > 3005001)
+#include <libedataserver/libedataserver.h>
+#else
 #include <libedataserver/e-data-server-util.h>
+#endif
+
 #include <mail/em-folder-tree.h>
+
+#if (EVOLUTION_VERSION > 30501)
+#include <em-format/e-mail-formatter.h>
+#else
 #include <mail/em-format-html.h>
+#endif
+
 #include <sys/time.h>
 #include <string.h>
 
@@ -43,9 +55,12 @@ extern rssfeed *rf;
 gchar *pixfile;
 char *pixfilebuf;
 gsize pixfilelen;
-extern GHashTable *icons;
 GHashTable *missing;
 
+#if (EVOLUTION_VERSION >= 30400)
+#include <mail/e-mail-reader.h>
+#endif
+
 void
 #if LIBSOUP_VERSION < 2003000
 finish_image_feedback (SoupMessage *msg, FEED_IMAGE *user_data);
@@ -289,6 +304,7 @@ finish_image_feedback (SoupSession *soup_sess, SoupMessage *msg, FEED_IMAGE *use
 {
 	CamelStream *stream = NULL;
 	gchar *mime_type;
+	d("finish_image_feedback()");
 	stream = rss_cache_add(user_data->url);
 	finish_image(soup_sess, msg, stream);
 	if (!missing)
@@ -313,13 +329,7 @@ finish_image_feedback (SoupSession *soup_sess, SoupMessage *msg, FEED_IMAGE *use
 				GINT_TO_POINTER(1));
 		}
 	g_free(mime_type);
-
-	if (user_data->data == current_pobject)
-#if EVOLUTION_VERSION >= 23190
-		em_format_queue_redraw((EMFormat *)user_data->data);
-#else
-		em_format_redraw((EMFormat *)user_data->data);
-#endif
+	e_mail_display_load_images(user_data->data);
 	g_free(user_data->url);
 	g_free(user_data);
 }
@@ -473,8 +483,7 @@ display_folder_icon(GtkTreeStore *tree_store, gchar *key)
 		}
 		icon = rss_build_icon (img_file, GTK_ICON_SIZE_MENU);
 		d("icon:%p\n", icon);
-		g_hash_table_insert(icons,
-			g_strdup(key), GINT_TO_POINTER(1));
+		rss_append_folder_icons(g_strdup(key));
 		sizes = gtk_icon_theme_get_icon_sizes(
 				gtk_icon_theme_get_default(),
 				"mail-read"); //will mail-read always be there?
@@ -485,12 +494,8 @@ display_folder_icon(GtkTreeStore *tree_store, gchar *key)
 				icon);
 		g_free(sizes);
 
-#if EVOLUTION_VERSION < 22900 //kb//
-		si = g_hash_table_lookup (mod->store_hash, store);
-#else
 		si = em_folder_tree_model_lookup_store_info (
 			EM_FOLDER_TREE_MODEL (mod), store);
-#endif
 		row = g_hash_table_lookup (si->full_hash, full_name);
 		if (!row) goto out;
 		path = gtk_tree_row_reference_get_path (row);
@@ -575,10 +580,13 @@ file_is_image(gchar *image, gboolean cleanup)
  * because we could end up with wrong file as image
  */
 gchar *
-verify_image(gchar *uri, EMFormatHTML *format)
+verify_image(gchar *uri, EMailDisplay *format)
 {
 	gchar *nurl, *turl;
 	gchar *feed_dir, *name;
+#if (EVOLUTION_VERSION >= 30400)
+	gchar *tmp = NULL;
+#endif
 	gchar *scheme, *tname;
 	gchar *result = NULL;
 	gchar *duri = NULL;
@@ -637,7 +645,13 @@ out:	if (!g_file_test(duri, G_FILE_TEST_EXISTS)) {
 				tname = decode_image_cache_filename(name);
 				g_free(name);
 #if (EVOLUTION_VERSION >= 23000)
+#if (EVOLUTION_VERSION < 30400)
 				result = g_filename_to_uri (tname, NULL, NULL);
+#else
+				tmp = g_filename_to_uri (tname, NULL, NULL);
+				result = g_strconcat("evo-", tmp, NULL);
+				g_free(tmp);
+#endif
 #else
 				result = g_strdup(tname);
 #endif
@@ -660,14 +674,22 @@ out:	if (!g_file_test(duri, G_FILE_TEST_EXISTS)) {
  * http://git.gnome.org/browse/evolution/commit/?id=d9deaf9bbc7fd9d0c72d5cf9b1981e3a56ed1162
  */
 #if (EVOLUTION_VERSION >= 23000)
+#if (EVOLUTION_VERSION < 30400)
 		return g_filename_to_uri(duri?duri:uri, NULL, NULL);
+#else
+		return g_strconcat("evo-file://", duri?duri:uri, NULL);
+#endif
 #else
 		return duri?duri:uri;
 #endif
 	}
 fail:
 #if (EVOLUTION_VERSION >= 23000)
+#if (EVOLUTION_VERSION < 30400)
 			result = g_filename_to_uri (pixfile, NULL, NULL);
+#else
+			result = g_strconcat("evo-file://", pixfile, NULL);
+#endif
 #else
 			result = g_strdup(pixfile);
 #endif
